@@ -1,7 +1,7 @@
 /* gnopi.c
  *
- * Copyright 2001, 2002 Sun Microsystems, Inc.,
- * Copyright 2001, 2002 BAUM Retec, A.G.
+ * Copyright 2001 - 2005 Sun Microsystems, Inc.,
+ * Copyright 2001 - 2005 BAUM Retec, A.G.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -304,6 +304,10 @@ main (gint argc,gchar *argv[])
 			NULL);
     sru_log_init ();
 
+/* FIXME the next line will be available only starting with gtk+ 2.6 */
+    /* gtk_window_set_default_icon_name ("gnopernicus"); */
+    gtk_window_set_default_icon_from_file (GNOPERNICUS_ICON, NULL);
+
     if (!gn_init_gconf ()) 
     {
         sru_warning (_("Gconf initialization failed."));
@@ -530,6 +534,7 @@ gn_check_accessibility_key (void)
     GladeXML	*xml    = NULL;
     gint         response_id;
     gboolean     accessibility_on;
+    AtkObject *obj;
     
     /* check if accessibility flag is TRUE */
     accessibility_on = 	gnopiconf_get_bool (ACCESSIBILITY_GCONF_KEY, 
@@ -550,7 +555,7 @@ gn_check_accessibility_key (void)
     
     g_object_unref (G_OBJECT (xml));
     
-    AtkObject *obj = gtk_widget_get_accessible (dialog);
+    obj = gtk_widget_get_accessible (dialog);
     atk_object_set_role (obj, ATK_ROLE_ALERT);
     
     response_id = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -563,6 +568,8 @@ gn_check_accessibility_key (void)
 	
     if (response_id == GTK_RESPONSE_YES)
     {
+        AtkObject *obj;
+
 	gnopiconf_set_bool (TRUE, ACCESSIBILITY_GCONF_KEY);
 	
 	xml 	= gn_load_interface ("gnopi.glade2", "dl_logout");	
@@ -570,7 +577,7 @@ gn_check_accessibility_key (void)
 	
 	g_object_unref (G_OBJECT (xml));
 	
-        AtkObject *obj = gtk_widget_get_accessible (dialog);
+        obj = gtk_widget_get_accessible (dialog);
         atk_object_set_role (obj, ATK_ROLE_ALERT);
         
 	response_id = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -581,8 +588,8 @@ gn_check_accessibility_key (void)
 	    return TRUE;
 	if (response_id == GTK_RESPONSE_YES)
 	{
-	    GnomeClient *client = NULL;
-	    if (client = gnome_master_client ()) 
+	    GnomeClient *client = gnome_master_client ();
+	    if (client)
 		gnome_client_request_save (client, GNOME_SAVE_GLOBAL, TRUE, 
 					GNOME_INTERACT_ANY, FALSE, TRUE);
 	    return TRUE;
